@@ -1,3 +1,10 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 var Path   = require('path'),
     _      = require('lodash'),
     models = require('../models');
@@ -26,12 +33,12 @@ module.exports = function(config, params) {
   this.timePeriods = new models.TimeIntervalBuilder(configuration.dateFormat)
     .from(this.parameters.dateFrom)
     .to(this.parameters.dateTo)
-    .split(this.parameters.frequency)
+    .split(this.parameters.timeSplit)
     .build();
 
   this.dateRange = new models.TimePeriod(
-    _.first(this.timePeriods).startDate,
-    _.last(this.timePeriods).endDate
+    { start: _.first(this.timePeriods).startDate, end: _.last(this.timePeriods).endDate },
+    configuration.dateFormat
   );
 
   this.boundaries = (configuration.architecturalBoundaries || {})[this.parameters.boundary];
