@@ -1,16 +1,16 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 var fs = require('fs'),
     _  = require('lodash'),
     Q  = require('q');
 
 var queryEntity = function(queryFn, path) {
-  try {
-    return fs.statSync(path)[queryFn]();
-  } catch(e) {
-    if (e instanceof Error && e.code !== 'ENOENT') {
-      throw e;
-    }
-  }
-  return false;
+  return fs.existsSync(path) && fs.statSync(path)[queryFn]();
 };
 
 module.exports = {
